# Economic Arena for Large Language Model(LLM) - Under Development

## Integrated LLM agent
| Series          | Models                 |
|-----------------|------------------------|
| OpenAI          | gpt-3.5, gpt-4         |
| Google DeepMind | PaLM2, Gemini-Pro      |
| Anthropic       | Claude, Claude-instant |
| Baichuan AI     | Baichuan2              |


## To use this package

Python requires **>= 3.9**

dependency requirements in `requirements.txt`

### 1. Clone the repository

```
git clone https://github.com/PinkEx/econ_arena_dev.git
cd econ_arena_dev
```
### 2. Setup the environment
The setup is tested on Python 3.8
```
python -m venv .env
```

In Windows:
```
.env\Scripts\activate
```

In Linux:
```
.env/bin/activate 
```

### 3. Install the dependencies
```
pip -r install requirements.txt
```

### 4. Write your script
In `example.py` you can write your script and run it.

To successfully run a script, you have to complete 3 steps in the script:

1. initial a `Host` instance
2. set api configurations
3. run the game and fetch the result in dict type

After that, just call `python example.py` and start your game with LLMs!